@@ -24,6 +24,7 @@ import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Hashtable;
@@ -906,7 +907,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 		}
 
 		ArrayList<CompareFilterDescriptor> list = new ArrayList<>(result);
-		Collections.sort(list, (left, right) -> left.getFilterId().compareTo(right.getFilterId()));
+		Collections.sort(list, Comparator.comparing(CompareFilterDescriptor::getFilterId));
 
 		return result.toArray(new CompareFilterDescriptor[result.size()]);
 	}
@@ -973,10 +974,8 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 		String rightType = guessType(input.getRight());
 
 		if (leftType != null || rightType != null) {
-			boolean right_text = rightType != null
-					&& ITypedElement.TEXT_TYPE.equals(rightType);
-			boolean left_text = leftType != null
-					&& ITypedElement.TEXT_TYPE.equals(leftType);
+			boolean right_text = ITypedElement.TEXT_TYPE.equals(rightType);
+			boolean left_text = ITypedElement.TEXT_TYPE.equals(leftType);
 			if ((rightType != null && !right_text)
 					|| (leftType != null && !left_text)) {
 				result.add(BINARY_TYPE);
@@ -1063,10 +1062,8 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 		String rightType= guessType(input.getRight());
 
 		if (leftType != null || rightType != null) {
-			boolean right_text = rightType != null
-					&& ITypedElement.TEXT_TYPE.equals(rightType);
-			boolean left_text = leftType != null
-					&& ITypedElement.TEXT_TYPE.equals(leftType);
+			boolean right_text = ITypedElement.TEXT_TYPE.equals(rightType);
+			boolean left_text = ITypedElement.TEXT_TYPE.equals(leftType);
 			initializeRegistries();
 			if ((rightType != null && !right_text)
 					|| (leftType != null && !left_text)) {
@@ -1499,10 +1496,8 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 		String rightType= guessType(input.getRight());
 
 		if (leftType != null || rightType != null) {
-			boolean right_text = rightType != null
-					&& ITypedElement.TEXT_TYPE.equals(rightType);
-			boolean left_text = leftType != null
-					&& ITypedElement.TEXT_TYPE.equals(leftType);
+			boolean right_text = ITypedElement.TEXT_TYPE.equals(rightType);
+			boolean left_text = ITypedElement.TEXT_TYPE.equals(leftType);
 			initializeRegistries();
 			if ((rightType != null && !right_text)
 					|| (leftType != null && !left_text)) {
