@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2008, 2017 Aleksandra Wozniak and others.
+ * Copyright (c) 2008, 2021 Aleksandra Wozniak and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -46,6 +46,7 @@ import org.eclipse.swt.dnd.DropTarget;
 import org.eclipse.swt.dnd.DropTargetEvent;
 import org.eclipse.swt.dnd.DropTargetListener;
 import org.eclipse.swt.dnd.TextTransfer;
+import org.eclipse.swt.dnd.TransferData;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
@@ -59,10 +60,12 @@ import org.eclipse.swt.widgets.FileDialog;
 import org.eclipse.swt.widgets.Group;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.forms.events.ExpansionAdapter;
 import org.eclipse.ui.forms.events.ExpansionEvent;
 import org.eclipse.ui.forms.widgets.ExpandableComposite;
 import org.eclipse.ui.part.ResourceTransfer;
+import org.osgi.framework.FrameworkUtil;
 
 /**
  * This is a dialog that can invoke the compare editor on chosen files.
@@ -73,7 +76,7 @@ public class CompareWithOtherResourceDialog extends TitleAreaDialog {
 	private int MIN_HEIGHT_WITH_ANCESTOR = 320;
 	private int MIN_HEIGHT_WITHOUT_ANCESTOR = 238;
 
-	private class FileTextDragListener implements DragSourceListener {
+	private static class FileTextDragListener implements DragSourceListener {
 
 		private ContentTypeElement element;
 
@@ -98,7 +101,7 @@ public class CompareWithOtherResourceDialog extends TitleAreaDialog {
 		}
 	}
 
-	private class FileTextDropListener implements DropTargetListener {
+	private static class FileTextDropListener implements DropTargetListener {
 
 		private ContentTypeElement element;
 		private ResourceTransfer resourceTransfer;
@@ -120,10 +123,10 @@ public class CompareWithOtherResourceDialog extends TitleAreaDialog {
 					event.detail = DND.DROP_NONE;
 			}
 
-			for (int i = 0; i < event.dataTypes.length; i++) {
-				if (resourceTransfer.isSupportedType(event.dataTypes[i])
-						|| textTransfer.isSupportedType(event.dataTypes[i])) {
-					event.currentDataType = event.dataTypes[i];
+			for (TransferData dataType : event.dataTypes) {
+				if (resourceTransfer.isSupportedType(dataType)
+						|| textTransfer.isSupportedType(dataType)) {
+					event.currentDataType = dataType;
 					if (event.detail != DND.DROP_COPY)
 						event.detail = DND.DROP_NONE;
 					break;
@@ -178,7 +181,7 @@ public class CompareWithOtherResourceDialog extends TitleAreaDialog {
 
 	}
 
-	private abstract class ContentTypeElement {
+	private abstract static class ContentTypeElement {
 
 		private Button radioButton;
 		protected Button mainButton;
@@ -811,7 +814,9 @@ public class CompareWithOtherResourceDialog extends TitleAreaDialog {
 	@Override
 	protected IDialogSettings getDialogBoundsSettings() {
 		String sectionName = getClass().getName() + "_dialogBounds"; //$NON-NLS-1$
-		IDialogSettings settings = CompareUIPlugin.getDefault().getDialogSettings();
+		IDialogSettings settings = PlatformUI
+				.getDialogSettingsProvider(FrameworkUtil.getBundle(CompareWithOtherResourceDialog.class))
+				.getDialogSettings();
 		IDialogSettings section = settings.getSection(sectionName);
 		if (section == null)
 			section = settings.addNewSection(sectionName);
