@@ -13,19 +13,51 @@
  *******************************************************************************/
 package org.eclipse.team.core.mapping.provider;
 
-import java.io.*;
-import java.util.*;
+import java.io.BufferedInputStream;
+import java.io.BufferedOutputStream;
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.OutputStream;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.List;
 
-import org.eclipse.core.resources.*;
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.resources.IContainer;
+import org.eclipse.core.resources.IFile;
+import org.eclipse.core.resources.IFolder;
+import org.eclipse.core.resources.IResource;
+import org.eclipse.core.resources.IResourceRuleFactory;
+import org.eclipse.core.resources.IStorage;
+import org.eclipse.core.resources.IWorkspace;
+import org.eclipse.core.resources.IWorkspaceRunnable;
+import org.eclipse.core.resources.ResourcesPlugin;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
 import org.eclipse.core.runtime.jobs.MultiRule;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.team.core.diff.IDiff;
 import org.eclipse.team.core.diff.IThreeWayDiff;
 import org.eclipse.team.core.history.IFileRevision;
-import org.eclipse.team.core.mapping.*;
-import org.eclipse.team.internal.core.*;
+import org.eclipse.team.core.mapping.DelegatingStorageMerger;
+import org.eclipse.team.core.mapping.IMergeContext;
+import org.eclipse.team.core.mapping.IMergeStatus;
+import org.eclipse.team.core.mapping.IResourceDiff;
+import org.eclipse.team.core.mapping.IResourceDiffTree;
+import org.eclipse.team.core.mapping.IResourceMappingMerger;
+import org.eclipse.team.core.mapping.IStorageMerger;
+import org.eclipse.team.core.mapping.ISynchronizationScopeManager;
+import org.eclipse.team.internal.core.Messages;
+import org.eclipse.team.internal.core.Policy;
+import org.eclipse.team.internal.core.TeamPlugin;
 import org.eclipse.team.internal.core.mapping.SyncInfoToDiffConverter;
 
 /**
@@ -41,41 +73,41 @@ import org.eclipse.team.internal.core.mapping.SyncInfoToDiffConverter;
 public abstract class MergeContext extends SynchronizationContext implements IMergeContext {
 
 	/**
-     * Create a merge context.
-	 * @param type
-     */
-    protected MergeContext(ISynchronizationScopeManager manager, int type, IResourceDiffTree deltaTree) {
-    	super(manager, type, deltaTree);
-    }
+	 * Create a merge context.
+	 *
+	 * @param manager   the manager that defines the scope of the synchronization
+	 * @param type      the type of synchronization (ONE_WAY or TWO_WAY)
+	 * @param deltaTree the sync info tree that contains all out-of-sync resources
+	 */
+	protected MergeContext(ISynchronizationScopeManager manager, int type, IResourceDiffTree deltaTree) {
+		super(manager, type, deltaTree);
+	}
 
-    @Override
+	@Override
 	public void reject(final IDiff[] diffs, IProgressMonitor monitor) throws CoreException {
 		run(monitor1 -> {
-			for (int i = 0; i < diffs.length; i++) {
-				IDiff node = diffs[i];
+			for (IDiff node : diffs) {
 				reject(node, monitor1);
 			}
 		}, getMergeRule(diffs), IResource.NONE, monitor);
-    }
+	}
 
-    @Override
+	@Override
 	public void markAsMerged(final IDiff[] nodes, final boolean inSyncHint, IProgressMonitor monitor) throws CoreException {
 		run(monitor1 -> {
-			for (int i = 0; i < nodes.length; i++) {
-				IDiff node = nodes[i];
+			for (IDiff node : nodes) {
 				markAsMerged(node, inSyncHint, monitor1);
 			}
 		}, getMergeRule(nodes), IResource.NONE, monitor);
-    }
+	}
 
-    @Override
+	@Override
 	public IStatus merge(final IDiff[] deltas, final boolean force, IProgressMonitor monitor) throws CoreException {
 		final List<IFile> failedFiles = new ArrayList<>();
 		run(monitor1 -> {
 			try {
 				monitor1.beginTask(null, deltas.length * 100);
-				for (int i = 0; i < deltas.length; i++) {
-					IDiff delta = deltas[i];
+				for (IDiff delta : deltas) {
 					IStatus s = merge(delta, force, Policy.subMonitorFor(monitor1, 100));
 					if (!s.isOK()) {
 						if (s.getCode() == IMergeStatus.CONFLICTS) {
@@ -94,7 +126,7 @@ public abstract class MergeContext extends SynchronizationContext implements IMe
 		} else {
 			return new MergeStatus(TeamPlugin.ID, Messages.MergeContext_0, failedFiles.toArray(new IFile[failedFiles.size()]));
 		}
-    }
+	}
 
 	@Override
 	public IStatus merge(IDiff diff, boolean ignoreLocalChanges, IProgressMonitor monitor) throws CoreException {
@@ -121,30 +153,30 @@ public abstract class MergeContext extends SynchronizationContext implements IMe
 			}
 			return Status.OK_STATUS;
 		}
-    	if (diff instanceof IThreeWayDiff && !ignoreLocalChanges && getMergeType() == THREE_WAY) {
+		if (diff instanceof IThreeWayDiff && !ignoreLocalChanges && getMergeType() == THREE_WAY) {
 			IThreeWayDiff twDelta = (IThreeWayDiff) diff;
-        	int direction = twDelta.getDirection();
-    		if (direction == IThreeWayDiff.OUTGOING) {
-        		// There's nothing to do so return OK
-        		return Status.OK_STATUS;
-        	}
-    		if (direction == IThreeWayDiff.INCOMING) {
-    			// Just copy the stream since there are no conflicts
-    			performReplace(diff, monitor);
-    			return Status.OK_STATUS;
-    		}
+			int direction = twDelta.getDirection();
+			if (direction == IThreeWayDiff.OUTGOING) {
+				// There's nothing to do so return OK
+				return Status.OK_STATUS;
+			}
+			if (direction == IThreeWayDiff.INCOMING) {
+				// Just copy the stream since there are no conflicts
+				performReplace(diff, monitor);
+				return Status.OK_STATUS;
+			}
 			// direction == SyncInfo.CONFLICTING
-    		int type = twDelta.getKind();
-    		if (type == IDiff.REMOVE) {
-    			makeInSync(diff, monitor);
-    			return Status.OK_STATUS;
-    		}
+			int type = twDelta.getKind();
+			if (type == IDiff.REMOVE) {
+				makeInSync(diff, monitor);
+				return Status.OK_STATUS;
+			}
 			// type == SyncInfo.CHANGE
 			IResourceDiff remoteChange = (IResourceDiff)twDelta.getRemoteChange();
 			IFileRevision remote = null;
-        	if (remoteChange != null) {
-	        	remote = remoteChange.getAfterState();
-        	}
+			if (remoteChange != null) {
+				remote = remoteChange.getAfterState();
+			}
 			if (remote == null || !getLocalFile(diff).exists()) {
 				// Nothing we can do so return a conflict status
 				// TODO: Should we handle the case where the local and remote have the same contents for a conflicting addition?
@@ -152,11 +184,11 @@ public abstract class MergeContext extends SynchronizationContext implements IMe
 			}
 			// We have a conflict, a local, base and remote so we can do
 			// a three-way merge
-            return performThreeWayMerge(twDelta, monitor);
-    	} else {
-    		performReplace(diff, monitor);
-    		return Status.OK_STATUS;
-    	}
+			return performThreeWayMerge(twDelta, monitor);
+		} else {
+			performReplace(diff, monitor);
+			return Status.OK_STATUS;
+		}
 
 	}
 
@@ -201,70 +233,70 @@ public abstract class MergeContext extends SynchronizationContext implements IMe
 					status = new MergeStatus(status.getPlugin(), status.getMessage(), new IFile[]{file});
 				}
 				result[0] = status;
-		    } finally {
-		        disposeTempOutputStream(file, os);
-		    }
-		    monitor1.done();
+			} finally {
+				disposeTempOutputStream(file, os);
+			}
+			monitor1.done();
 		}, getMergeRule(diff), IWorkspace.AVOID_UPDATE, monitor);
 		return result[0];
 	}
 
-    private void disposeTempOutputStream(IFile file, OutputStream output) {
-        if (output instanceof ByteArrayOutputStream)
-            return;
-        // We created a temporary file so we need to clean it up
-        try {
-            // First make sure the output stream is closed
-            // so that file deletion will not fail because of that.
-            if (output != null)
-                output.close();
-        } catch (IOException e) {
-            // Ignore
-        }
-        File tmpFile = getTempFile(file);
-        if (tmpFile.exists())
-            tmpFile.delete();
-    }
+	private void disposeTempOutputStream(IFile file, OutputStream output) {
+		if (output instanceof ByteArrayOutputStream)
+			return;
+		// We created a temporary file so we need to clean it up
+		try {
+			// First make sure the output stream is closed
+			// so that file deletion will not fail because of that.
+			if (output != null)
+				output.close();
+		} catch (IOException e) {
+			// Ignore
+		}
+		File tmpFile = getTempFile(file);
+		if (tmpFile.exists())
+			tmpFile.delete();
+	}
 
-    private OutputStream getTempOutputStream(IFile file) throws CoreException {
-        File tmpFile = getTempFile(file);
-        if (tmpFile.exists())
-            tmpFile.delete();
-        File parent = tmpFile.getParentFile();
-        if (!parent.exists())
-        	parent.mkdirs();
-        try {
-            return new BufferedOutputStream(new FileOutputStream(tmpFile));
-        } catch (FileNotFoundException e) {
-            TeamPlugin.log(IStatus.ERROR, NLS.bind("Could not open temporary file {0} for writing: {1}", new String[] { tmpFile.getAbsolutePath(), e.getMessage() }), e); //$NON-NLS-1$
-            return new ByteArrayOutputStream();
-        }
-    }
+	private OutputStream getTempOutputStream(IFile file) throws CoreException {
+		File tmpFile = getTempFile(file);
+		if (tmpFile.exists())
+			tmpFile.delete();
+		File parent = tmpFile.getParentFile();
+		if (!parent.exists())
+			parent.mkdirs();
+		try {
+			return new BufferedOutputStream(new FileOutputStream(tmpFile));
+		} catch (FileNotFoundException e) {
+			TeamPlugin.log(IStatus.ERROR, NLS.bind("Could not open temporary file {0} for writing: {1}", new String[] { tmpFile.getAbsolutePath(), e.getMessage() }), e); //$NON-NLS-1$
+			return new ByteArrayOutputStream();
+		}
+	}
 
-    private InputStream getTempInputStream(IFile file, OutputStream output) throws CoreException {
-        if (output instanceof ByteArrayOutputStream) {
-            ByteArrayOutputStream baos = (ByteArrayOutputStream) output;
-            return new ByteArrayInputStream(baos.toByteArray());
-        }
-        // We created a temporary file so we need to open an input stream on it
-        try {
-            // First make sure the output stream is closed
-            if (output != null)
-                output.close();
-        } catch (IOException e) {
-            // Ignore
-        }
-        File tmpFile = getTempFile(file);
-        try {
-            return new BufferedInputStream(new FileInputStream(tmpFile));
-        } catch (FileNotFoundException e) {
-            throw new CoreException(new Status(IStatus.ERROR, TeamPlugin.ID, IMergeStatus.INTERNAL_ERROR, NLS.bind(Messages.MergeContext_4, new String[] { tmpFile.getAbsolutePath(), e.getMessage() }), e));
-        }
-    }
+	private InputStream getTempInputStream(IFile file, OutputStream output) throws CoreException {
+		if (output instanceof ByteArrayOutputStream) {
+			ByteArrayOutputStream baos = (ByteArrayOutputStream) output;
+			return new ByteArrayInputStream(baos.toByteArray());
+		}
+		// We created a temporary file so we need to open an input stream on it
+		try {
+			// First make sure the output stream is closed
+			if (output != null)
+				output.close();
+		} catch (IOException e) {
+			// Ignore
+		}
+		File tmpFile = getTempFile(file);
+		try {
+			return new BufferedInputStream(new FileInputStream(tmpFile));
+		} catch (FileNotFoundException e) {
+			throw new CoreException(new Status(IStatus.ERROR, TeamPlugin.ID, IMergeStatus.INTERNAL_ERROR, NLS.bind(Messages.MergeContext_4, new String[] { tmpFile.getAbsolutePath(), e.getMessage() }), e));
+		}
+	}
 
-    private File getTempFile(IFile file) {
-        return TeamPlugin.getPlugin().getStateLocation().append(".tmp").append(file.getName() + ".tmp").toFile(); //$NON-NLS-1$ //$NON-NLS-2$
-    }
+	private File getTempFile(IFile file) {
+		return TeamPlugin.getPlugin().getStateLocation().append(".tmp").append(file.getName() + ".tmp").toFile(); //$NON-NLS-1$ //$NON-NLS-2$
+	}
 
 	private IFile getLocalFile(IDiff delta) {
 		return ResourcesPlugin.getWorkspace().getRoot().getFile(delta.getPath());
@@ -284,33 +316,33 @@ public abstract class MergeContext extends SynchronizationContext implements IMe
 	 *            the diff whose local is to be replaced
 	 * @param monitor
 	 *            a progress monitor
-	 * @throws CoreException
+	 * @throws CoreException if an error occurs
 	 */
-    protected void performReplace(final IDiff diff, IProgressMonitor monitor) throws CoreException {
-    	IResourceDiff d;
-    	IFile file = getLocalFile(diff);
-    	IFileRevision remote = null;
-    	if (diff instanceof IResourceDiff) {
-    		d = (IResourceDiff) diff;
-   			remote = d.getAfterState();
-    	} else {
-    		d = (IResourceDiff)((IThreeWayDiff)diff).getRemoteChange();
-    		if (d != null)
-    			remote = d.getAfterState();
-    	}
-    	if (d == null) {
-    		d = (IResourceDiff)((IThreeWayDiff)diff).getLocalChange();
-    		if (d != null)
-    			remote = d.getBeforeState();
-    	}
+	protected void performReplace(final IDiff diff, IProgressMonitor monitor) throws CoreException {
+		IResourceDiff d;
+		IFile file = getLocalFile(diff);
+		IFileRevision remote = null;
+		if (diff instanceof IResourceDiff) {
+			d = (IResourceDiff) diff;
+			remote = d.getAfterState();
+		} else {
+			d = (IResourceDiff)((IThreeWayDiff)diff).getRemoteChange();
+			if (d != null)
+				remote = d.getAfterState();
+		}
+		if (d == null) {
+			d = (IResourceDiff)((IThreeWayDiff)diff).getLocalChange();
+			if (d != null)
+				remote = d.getBeforeState();
+		}
 
-    	// Only perform the replace if a local or remote change was found
-    	if (d != null) {
-	    	performReplace(diff, file, remote, monitor);
-    	}
+		// Only perform the replace if a local or remote change was found
+		if (d != null) {
+			performReplace(diff, file, remote, monitor);
+		}
 	}
 
-    /**
+	/**
 	 * Method that is invoked from
 	 * {@link #performReplace(IDiff, IProgressMonitor)} after the local has been
 	 * changed to match the remote. Subclasses may override
@@ -324,9 +356,9 @@ public abstract class MergeContext extends SynchronizationContext implements IMe
 	 *            the diff whose local is now in-sync
 	 * @param monitor
 	 *            a progress monitor
-	 * @throws CoreException
+	 * @throws CoreException if an error occurs
 	 */
-    protected abstract void makeInSync(IDiff diff, IProgressMonitor monitor) throws CoreException;
+	protected abstract void makeInSync(IDiff diff, IProgressMonitor monitor) throws CoreException;
 
 	private void performReplace(final IDiff diff, final IFile file, final IFileRevision remote, IProgressMonitor monitor) throws CoreException {
 		run(monitor1 -> {
@@ -424,8 +456,7 @@ public abstract class MergeContext extends SynchronizationContext implements IMe
 	@Override
 	public ISchedulingRule getMergeRule(IDiff[] deltas) {
 		ISchedulingRule result = null;
-		for (int i = 0; i < deltas.length; i++) {
-			IDiff node = deltas[i];
+		for (IDiff node : deltas) {
 			ISchedulingRule rule = getMergeRule(node);
 			if (result == null) {
 				result = rule;
