@@ -13,7 +13,7 @@
  *******************************************************************************/
 package org.eclipse.team.internal.ccvs.core.mapping;
 
-import com.ibm.icu.text.DateFormat;
+import java.text.DateFormat;
 import java.util.Date;
 
 import org.eclipse.team.internal.ccvs.core.ILogEntry;
