@@ -44,7 +44,7 @@ public class RemoteFolderTreeBuilder {
 
 	private static final int MAX_REVISION_FETCHES_PER_CONNECTION = 1024;
 	
-	private Map<String, Map> fileDeltas;
+	private Map<String, Map<String, DeltaNode>> fileDeltas;
 	private List<String> changedFiles;
 	private Map<String, RemoteFolderTree> remoteFolderTable;
 	
@@ -96,9 +96,9 @@ public class RemoteFolderTreeBuilder {
 		this.repository = repository;
 		this.root = root;
 		this.tag = tag;
-		this.fileDeltas = new HashMap<String, Map>();
-		this.changedFiles = new ArrayList<String>();
-		this.remoteFolderTable = new HashMap<String, RemoteFolderTree>();
+		this.fileDeltas = new HashMap<>();
+		this.changedFiles = new ArrayList<>();
+		this.remoteFolderTable = new HashMap<>();
 		
 		// Build the local options
 		List<LocalOption> localOptions = new ArrayList<>();
@@ -178,8 +178,7 @@ public class RemoteFolderTreeBuilder {
 		
 		// Get the arguments from the files
 		ArrayList<String> arguments = new ArrayList<>();
-		for (int i = 0; i < resources.length; i++) {
-			ICVSResource resource = resources[i];
+		for (ICVSResource resource : resources) {
 			arguments.add(resource.getRelativePath(root));
 		}
 		
@@ -381,8 +380,8 @@ public class RemoteFolderTreeBuilder {
 		
 		// Build the child folders corresponding to local folders base
 		ICVSResource[] folders = local.members(ICVSFolder.FOLDER_MEMBERS);
-		for (int i=0;i<folders.length;i++) {
-			ICVSFolder folder = (ICVSFolder)folders[i];
+		for (ICVSResource f : folders) {
+			ICVSFolder folder = (ICVSFolder) f;
 			if (folder.isManaged() && folder.isCVSFolder()) {
 				monitor.worked(1);
 				RemoteFolder tree = buildBaseTree(remote, folder, monitor);
@@ -393,8 +392,8 @@ public class RemoteFolderTreeBuilder {
 		
 		// Build the child files corresponding to local files base
 		ICVSResource[] files = local.members(ICVSFolder.FILE_MEMBERS);
-		for (int i=0;i<files.length;i++) {
-			ICVSFile file = (ICVSFile)files[i];
+		for (ICVSResource f : files) {
+			ICVSFile file = (ICVSFile) f;
 			byte[] syncBytes = file.getSyncBytes();
 			// if there is no sync info then there is no base
 			if (syncBytes==null)
@@ -459,21 +458,17 @@ public class RemoteFolderTreeBuilder {
 		if (local != null) {
 			// Build the child folders corresponding to local folders
 			ICVSResource[] folders = local.members(ICVSFolder.FOLDER_MEMBERS);
-			for (int i=0;i<folders.length;i++) {
-				ICVSFolder folder = (ICVSFolder)folders[i];
+			for (ICVSResource f : folders) {
+				ICVSFolder folder = (ICVSFolder) f;
 				DeltaNode d = (DeltaNode)deltas.get(folder.getName());
 				if (folder.isCVSFolder() && ! isOrphanedSubtree(folder) && (d==null || d.getRevision() != DELETED)) {
-					children.put(folders[i].getName(), 
-						new RemoteFolderTree(remote, folders[i].getName(), repository, 
-							folder.getFolderSyncInfo().getRepository(), 
-							tagForRemoteFolder(folder,tag)));
+					children.put(f.getName(), new RemoteFolderTree(remote, f.getName(), repository, folder.getFolderSyncInfo().getRepository(), tagForRemoteFolder(folder,tag)));
 				}
 			}
 			// Build the child files corresponding to local files
 			ICVSResource[] files = local.members(ICVSFolder.FILE_MEMBERS);
-			for (int i=0;i<files.length;i++) {
-				ICVSFile file = (ICVSFile)files[i];
-
+			for (ICVSResource f : files) {
+				ICVSFile file = (ICVSFile) f;
 				DeltaNode d = (DeltaNode)deltas.get(file.getName());
 				byte[] syncBytes = file.getSyncBytes();
 				// if there is no sync info then there isn't a remote file for this local file on the
@@ -568,7 +563,7 @@ public class RemoteFolderTreeBuilder {
 		
 		// Prune any empty child folders
 		if (isPruneEmptyDirectories() && !emptyChildren.isEmpty()) {
-			List<ICVSRemoteResource> newChildren = new ArrayList<ICVSRemoteResource>();
+			List<ICVSRemoteResource> newChildren = new ArrayList<>();
 			newChildren.addAll(Arrays.asList(remote.getChildren()));
 			newChildren.removeAll(emptyChildren);
 			remote.setChildren(newChildren.toArray(new ICVSRemoteResource[newChildren.size()]));
@@ -714,7 +709,7 @@ public class RemoteFolderTreeBuilder {
 	private void fetchFileRevisions(Session session, String[] fileNames, final IProgressMonitor monitor) throws CVSException {
 		
 		// Create a listener for receiving the revision info
-		final List<CVSException> exceptions = new ArrayList<CVSException>();
+		final List<CVSException> exceptions = new ArrayList<>();
 		IStatusListener listener = new IStatusListener() {
 			public void fileStatus(ICVSFolder root, String path, String remoteRevision) {
 				try {
