@@ -82,7 +82,7 @@ import org.eclipse.team.internal.ccvs.core.util.Util;
 	
 	boolean hasCachedFolderSync(IContainer container) throws CVSException {
 		return internalGetCachedSyncBytes(container) != null;
-	};
+	}
 	
 	/*
 	 * Retieve the cached sync bytes from the synchronizer. A null
@@ -254,8 +254,7 @@ import org.eclipse.team.internal.ccvs.core.util.Util;
 		
 		String indicator = NOT_DIRTY_INDICATOR;
 		ICVSResource[] children = cvsFolder.members(ICVSFolder.MANAGED_MEMBERS | ICVSFolder.PHANTOM_MEMBERS);
-		for (int i = 0; i < children.length; i++) {
-			ICVSResource resource = children[i];
+		for (ICVSResource resource : children) {
 			// keep looking into phantom folders until a managed phantom file 
 			// is found.
 			if (resource.isFolder()) {
@@ -305,13 +304,12 @@ import org.eclipse.team.internal.ccvs.core.util.Util;
 		IResource[] pendingWrites = getPendingCacheWrites();
 		if (pendingWrites != null){
 			HashSet<IResource> cachedResources = new HashSet<>();
-			for (int i = 0; i < pendingWrites.length; i++) {
-				IResource resource = pendingWrites[i];
+			for (IResource resource : pendingWrites) {
 				if (resource.getParent().equals(folder))
 					cachedResources.add(resource);
 			}
 			
-			if (cachedResources.size() != 0){
+			if (!cachedResources.isEmpty()){
 				IResource[] resources = folder.members(true);
 				IResource[] cachedResourcesArray = cachedResources.toArray(new IResource[cachedResources.size()]);
 				IResource[]finalResources = new IResource[resources.length + cachedResourcesArray.length];
