@@ -18,6 +18,8 @@ package org.eclipse.team.internal.ccvs.ui;
 
 import java.io.InputStream;
 import java.lang.reflect.InvocationTargetException;
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
 import java.util.*;
 
 import org.eclipse.compare.*;
@@ -77,10 +79,6 @@ import org.eclipse.ui.part.IPageSite;
 import org.eclipse.ui.progress.IProgressConstants;
 import org.eclipse.ui.texteditor.ITextEditorActionConstants;
 
-import com.ibm.icu.text.DateFormat;
-import com.ibm.icu.text.SimpleDateFormat;
-import com.ibm.icu.util.Calendar;
-
 public class CVSHistoryPage extends HistoryPage implements IAdaptable, IHistoryCompareAdapter {
 	
 	/* private */ ICVSFile file;
@@ -1414,7 +1412,7 @@ public class CVSHistoryPage extends HistoryPage implements IAdaptable, IHistoryC
 		@Override
 		public void run() {
 			String searchString = searchField.getText();
-			if (searchString.equals("") || //$NON-NLS-1$
+			if (searchString.isEmpty() ||
 				searchString.equals(CVSUIMessages.CVSHistoryPage_EnterSearchTerm)) {
 				if (searchFilter != null)
 					treeViewer.removeFilter(searchFilter);
