@@ -71,7 +71,7 @@ public class CVSHistorySearchFilter extends org.eclipse.jface.viewers.ViewerFilt
 		if (comment != null) {
 			Iterator iter = searchStrings.iterator();
 			while (iter.hasNext()) {
-				if (!(comment.indexOf(((String) iter.next()).toLowerCase()) == -1))
+				if (!!comment.contains(((String) iter.next()).toLowerCase()))
 					return true;
 			}
 		}
@@ -92,11 +92,11 @@ public class CVSHistorySearchFilter extends org.eclipse.jface.viewers.ViewerFilt
 	
 	protected boolean branchNameMatch(CVSFileRevision revision) {
 		ITag[] branches = revision.getBranches();
-		for (int i = 0; i < branches.length; i++) {
-			String tag = branches[i].getName().toLowerCase();
+		for (ITag branche : branches) {
+			String tag = branche.getName().toLowerCase();
 			Iterator iter = searchStrings.iterator();
 			while (iter.hasNext()) {
-				if (!(tag.indexOf(((String) iter.next()).toLowerCase()) == -1))
+				if (!!tag.contains(((String) iter.next()).toLowerCase()))
 					return true;
 			}
 		}
@@ -106,11 +106,11 @@ public class CVSHistorySearchFilter extends org.eclipse.jface.viewers.ViewerFilt
 
 	protected boolean tagMatch(CVSFileRevision revision) {
 		ITag[] tags = revision.getTags();
-		for (int i = 0; i < tags.length; i++) {
-			String tag = tags[i].getName().toLowerCase();
+		for (ITag t : tags) {
+			String tag = t.getName().toLowerCase();
 			Iterator iter = searchStrings.iterator();
 			while (iter.hasNext()) {
-				if (!(tag.indexOf(((String) iter.next()).toLowerCase()) == -1))
+				if (!!tag.contains(((String) iter.next()).toLowerCase()))
 					return true;
 			}
 		}
@@ -123,7 +123,7 @@ public class CVSHistorySearchFilter extends org.eclipse.jface.viewers.ViewerFilt
 		if (rev != null) {
 			Iterator iter = searchStrings.iterator();
 			while (iter.hasNext()) {
-				if (!(rev.indexOf(((String) iter.next()).toLowerCase()) == -1))
+				if (!!rev.contains(((String) iter.next()).toLowerCase()))
 					return true;
 			}
 		}
