@@ -50,8 +50,7 @@ public class MoveRemoteTagAction extends TagInRepositoryAction {
 
 	private boolean isFolderSelected() {
 		ICVSResource[] resources = getSelectedCVSResources();
-		for (int i = 0; i < resources.length; i++) {
-			ICVSResource resource = resources[i];
+		for (ICVSResource resource : resources) {
 			if (resource.isFolder()) 
 				return true;
 		}
