@@ -30,10 +30,10 @@ public class OpenRemoteFileAction extends CVSAction {
 	 * Returns the selected remote files
 	 */
 	protected ICVSRemoteFile[] getSelectedRemoteFiles() {
-		ArrayList resources = null;
+		ArrayList<Object> resources = null;
 		IStructuredSelection selection = getSelection();
 		if (!selection.isEmpty()) {
-			resources = new ArrayList();
+			resources = new ArrayList<>();
 			Iterator elements = selection.iterator();
 			while (elements.hasNext()) {
 				Object next = elements.next();
@@ -62,9 +62,6 @@ public class OpenRemoteFileAction extends CVSAction {
 		}
 		return new ICVSRemoteFile[0];
 	}
-	/*
-	 * @see CVSAction#execute(IAction)
-	 */
 	@Override
 	public void execute(IAction action) throws InterruptedException, InvocationTargetException {
 		run((IRunnableWithProgress) monitor -> {
@@ -75,9 +72,7 @@ public class OpenRemoteFileAction extends CVSAction {
 			}
 		}, false, PROGRESS_BUSYCURSOR); 
 	}
-	/*
-	 * @see TeamAction#isEnabled()
-	 */
+
 	@Override
 	public boolean isEnabled() {
 		ICVSRemoteFile[] resources = getSelectedRemoteFiles();
