@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2010 IBM Corporation and others.
+ * Copyright (c) 2000, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,6 +16,7 @@ package org.eclipse.team.internal.ccvs.ui.operations;
 
 import java.io.IOException;
 import java.io.InputStream;
+import java.text.DateFormat;
 import java.util.*;
 
 import org.eclipse.core.resources.IFile;
@@ -50,8 +51,6 @@ import org.eclipse.ui.*;
 import org.eclipse.ui.editors.text.EditorsUI;
 import org.eclipse.ui.texteditor.AbstractDecoratedTextEditor;
 
-import com.ibm.icu.text.DateFormat;
-
 /**
  * An operation to fetch the annotations for a file from the repository and
  * display them in the annotations view.
@@ -139,6 +138,7 @@ public class ShowAnnotationOperation extends CVSOperation {
 		}
 	}
 
+	@SuppressWarnings("resource")
 	private AbstractDecoratedTextEditor getEditor(AnnotateListener listener) throws PartInitException {
 		IResource resource= fCVSResource.getIResource();
 		if (resource instanceof IFile){
