@@ -80,7 +80,7 @@ public class PasteAction extends SelectionListenerAction {
 				protected boolean isApplyPatchInSynchronizeView() {
 					// ignore the preference, apply in the sync view
 					return true;
-				};
+				}
 			};
 			operation.openWizard();
 		} else {
@@ -151,9 +151,10 @@ public class PasteAction extends SelectionListenerAction {
 
 	private static boolean isAvailable(Transfer transfer,
 			TransferData[] availableDataTypes) {
-		for (int i = 0; i < availableDataTypes.length; i++) {
-			if (transfer.isSupportedType(availableDataTypes[i]))
+		for (TransferData availableDataType : availableDataTypes) {
+			if (transfer.isSupportedType(availableDataType)) {
 				return true;
+			}
 		}
 		return false;
 	}
