@@ -18,7 +18,6 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Set;
 
@@ -153,8 +152,8 @@ public class ExportProjectSetMainPage extends TeamWizardPage {
 			} else if (inputElement instanceof HashSet){
 				Set<IProject> tempList = new HashSet<>();
 				HashSet inputElementSet = (HashSet) inputElement;
-				for (Iterator iterator = inputElementSet.iterator(); iterator.hasNext();) {
-					IProject[] projects = getProjectsForObject(iterator.next());
+				for (Object element : inputElementSet) {
+					IProject[] projects = getProjectsForObject(element);
 					if (projects != null)
 						tempList.addAll(Arrays.asList(projects));
 				}
@@ -256,8 +255,8 @@ public class ExportProjectSetMainPage extends TeamWizardPage {
 
 		// filter out unexportable projects
 		List passedInExportableProjects = new ArrayList();
-		for (Iterator iterator = passedInSelectedProjects.iterator(); iterator.hasNext();) {
-			IProject project = (IProject) iterator.next();
+		for (Object element : passedInSelectedProjects) {
+			IProject project = (IProject) element;
 			if (isProjectExportable(project))
 				passedInExportableProjects.add(project);
 		}
@@ -679,9 +678,8 @@ public class ExportProjectSetMainPage extends TeamWizardPage {
 			// check if there is at least one exportable project selected
 			if (complete || !pageShown) {
 				complete = false;
-				for (Iterator iterator = selectedProjects.iterator(); iterator
-						.hasNext();) {
-					IProject selectedProject = (IProject) iterator.next();
+				for (Object element : selectedProjects) {
+					IProject selectedProject = (IProject) element;
 					if (isProjectExportable(selectedProject)) {
 						complete = true;
 					} else {
@@ -745,8 +743,7 @@ public class ExportProjectSetMainPage extends TeamWizardPage {
 
 			if (!tempSet.isEmpty()) {
 				selectedProjects.removeAll(tempSet);
-				for (Iterator iterator = tempSet.iterator(); iterator.hasNext();) {
-					Object element = iterator.next();
+				for (Object element : tempSet) {
 					referenceCountProjects.remove(element);
 				}
 				selectedProjects.addAll(referenceCountProjects);
