@@ -13,8 +13,6 @@
  *******************************************************************************/
 package org.eclipse.team.tests.ccvs.ui;
 
-import junit.framework.AssertionFailedError;
-
 import org.eclipse.compare.structuremergeviewer.IDiffContainer;
 import org.eclipse.compare.structuremergeviewer.IDiffElement;
 import org.eclipse.core.resources.IProject;
@@ -59,6 +57,8 @@ import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.PartInitException;
 import org.eclipse.ui.part.IPage;
 
+import junit.framework.AssertionFailedError;
+
 /**
  * SyncInfoSource that obtains SyncInfo from the SynchronizeView's SyncSet.
  */
@@ -68,6 +68,7 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 		super();
 	}
 	
+	@Override
 	public SyncInfo getSyncInfo(Subscriber subscriber, IResource resource) throws TeamException {
 		// Wait for the collector
 		getCollector(subscriber);
@@ -100,9 +101,7 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 		return info;
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.tests.ccvs.core.subscriber.SyncInfoSource#getDiff(org.eclipse.team.core.subscribers.Subscriber, org.eclipse.core.resources.IResource)
-	 */
+	@Override
 	public IDiff getDiff(Subscriber subscriber, IResource resource) throws CoreException {
 		SyncInfo info = getSyncInfo(subscriber, resource);
 		if (info == null || info.getKind() == SyncInfo.IN_SYNC) {
@@ -114,10 +113,10 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 	public static SubscriberParticipant getParticipant(Subscriber subscriber) {
 		// show the sync view
 		ISynchronizeParticipantReference[] participants = TeamUI.getSynchronizeManager().getSynchronizeParticipants();
-		for (int i = 0; i < participants.length; i++) {
+		for (ISynchronizeParticipantReference participant2 : participants) {
 			ISynchronizeParticipant participant;
 			try {
-				participant = participants[i].getParticipant();
+				participant = participant2.getParticipant();
 			} catch (TeamException e) {
 				return null;
 			}
@@ -135,25 +134,33 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 		if (participant == null) return null;
 		SubscriberSyncInfoCollector syncInfoCollector = participant.getSubscriberSyncInfoCollector();
 		EclipseTest.waitForSubscriberInputHandling(syncInfoCollector);
-        SubscriberParticipantPage page = getPage(subscriber);
-        SynchronizeModelManager manager = (SynchronizeModelManager)page.getConfiguration().getProperty(SynchronizePageConfiguration.P_MODEL_MANAGER);
-        AbstractSynchronizeModelProvider provider = (AbstractSynchronizeModelProvider)manager.getActiveModelProvider();
-        provider.waitUntilDone(new IProgressMonitor() {
+		SubscriberParticipantPage page = getPage(subscriber);
+		SynchronizeModelManager manager = (SynchronizeModelManager)page.getConfiguration().getProperty(SynchronizePageConfiguration.P_MODEL_MANAGER);
+		AbstractSynchronizeModelProvider provider = (AbstractSynchronizeModelProvider)manager.getActiveModelProvider();
+		provider.waitUntilDone(new IProgressMonitor() {
+			@Override
 			public void beginTask(String name, int totalWork) {
 			}
+			@Override
 			public void done() {
 			}
+			@Override
 			public void internalWorked(double work) {
 			}
+			@Override
 			public boolean isCanceled() {
 				return false;
 			}
+			@Override
 			public void setCanceled(boolean value) {
 			}
+			@Override
 			public void setTaskName(String name) {
 			}
+			@Override
 			public void subTask(String name) {
 			}
+			@Override
 			public void worked(int work) {
 				while (Display.getCurrent().readAndDispatch()) {}
 			}
@@ -161,9 +168,7 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 		return syncInfoCollector;
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.tests.ccvs.core.subscriber.SyncInfoSource#assertProjectRemoved(org.eclipse.team.core.subscribers.TeamSubscriber, org.eclipse.core.resources.IProject)
-	 */
+	@Override
 	protected void assertProjectRemoved(Subscriber subscriber, IProject project) {		
 		super.assertProjectRemoved(subscriber, project);
 		SyncInfoTree set = getCollector(subscriber).getSyncInfoSet();
@@ -172,9 +177,7 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 		}
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.tests.ccvs.core.subscriber.SyncInfoSource#createMergeSubscriber(org.eclipse.core.resources.IProject, org.eclipse.team.internal.ccvs.core.CVSTag, org.eclipse.team.internal.ccvs.core.CVSTag)
-	 */
+	@Override
 	public CVSMergeSubscriber createMergeSubscriber(IProject project, CVSTag root, CVSTag branch, boolean isModelSync) {
 		CVSMergeSubscriber mergeSubscriber = super.createMergeSubscriber(project, root, branch, isModelSync);
 		SubscriberParticipant participant = new MergeSynchronizeParticipant(mergeSubscriber);
@@ -182,6 +185,7 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 		return mergeSubscriber;
 	}
 	
+	@Override
 	public Subscriber createWorkspaceSubscriber() throws TeamException {
 		ISynchronizeManager synchronizeManager = TeamUI.getSynchronizeManager();
 		ISynchronizeParticipantReference[] participants = synchronizeManager.get(WorkspaceSynchronizeParticipant.ID);
@@ -194,9 +198,7 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 	}
 	
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.tests.ccvs.core.subscriber.SyncInfoSource#createCompareSubscriber(org.eclipse.core.resources.IProject, org.eclipse.team.internal.ccvs.core.CVSTag)
-	 */
+	@Override
 	public CVSCompareSubscriber createCompareSubscriber(IResource resource, CVSTag tag) {
 		CVSCompareSubscriber s = super.createCompareSubscriber(resource, tag);
 		SubscriberParticipant participant = new CompareParticipant(s);
@@ -209,92 +211,91 @@ public class SubscriberParticipantSyncInfoSource extends ParticipantSyncInfoSour
 		return findSyncInfo(root, resource);
 	}
 	
-    private SyncInfo findSyncInfo(ISynchronizeModelElement node, IResource resource) {
-        if (node instanceof SyncInfoModelElement) {
-            SyncInfoModelElement element = (SyncInfoModelElement)node;
-            if (element.getResource().equals(resource)) {
-                return element.getSyncInfo();
-            }
-        }
-        IDiffElement[] children = node.getChildren();
-        for (int i = 0; i < children.length; i++) {
-            ISynchronizeModelElement child = (ISynchronizeModelElement)children[i];
-            SyncInfo info = findSyncInfo(child, resource);
-            if (info != null)
-                return info;
-        }
-        return null;
-    }
-    
-    public void assertViewMatchesModel(Subscriber subscriber) {
-    	// Getting the collector waits for the subscriber input handlers
-    	getCollector(subscriber);
+	private SyncInfo findSyncInfo(ISynchronizeModelElement node, IResource resource) {
+		if (node instanceof SyncInfoModelElement) {
+			SyncInfoModelElement element = (SyncInfoModelElement)node;
+			if (element.getResource().equals(resource)) {
+				return element.getSyncInfo();
+			}
+		}
+		IDiffElement[] children = node.getChildren();
+		for (IDiffElement element : children) {
+			ISynchronizeModelElement child = (ISynchronizeModelElement)element;
+			SyncInfo info = findSyncInfo(child, resource);
+			if (info != null)
+				return info;
+		}
+		return null;
+	}
+	
+	@Override
+	public void assertViewMatchesModel(Subscriber subscriber) {
+		// Getting the collector waits for the subscriber input handlers
+		getCollector(subscriber);
 		ISynchronizeModelElement root = getModelRoot(subscriber);
 		TreeItem[] rootItems = getTreeItems(subscriber);
 		assertMatchingTrees(root, rootItems, root.getChildren());
-    }
+	}
 
-    private ISynchronizeModelElement getModelRoot(Subscriber subscriber) {
-        SubscriberParticipantPage page = getPage(subscriber);
-        return ((TreeViewerAdvisor)page.getViewerAdvisor()).getModelManager().getModelRoot();
-    }
-    
-    private TreeItem[] getTreeItems(Subscriber subscriber) {
-        SubscriberParticipantPage page = getPage(subscriber);
-        Viewer v = page.getViewer();
-        if (v instanceof TreeViewer) {
-            TreeViewer treeViewer = (TreeViewer)v;
-            treeViewer.expandAll();
-            Tree t = (treeViewer).getTree();
-            return t.getItems();
-        }
-        throw new AssertionFailedError("The tree for " + subscriber.getName() + " could not be retrieved");
-    }
+	private ISynchronizeModelElement getModelRoot(Subscriber subscriber) {
+		SubscriberParticipantPage page = getPage(subscriber);
+		return ((TreeViewerAdvisor)page.getViewerAdvisor()).getModelManager().getModelRoot();
+	}
+	
+	private TreeItem[] getTreeItems(Subscriber subscriber) {
+		SubscriberParticipantPage page = getPage(subscriber);
+		Viewer v = page.getViewer();
+		if (v instanceof TreeViewer) {
+			TreeViewer treeViewer = (TreeViewer)v;
+			treeViewer.expandAll();
+			Tree t = (treeViewer).getTree();
+			return t.getItems();
+		}
+		throw new AssertionFailedError("The tree for " + subscriber.getName() + " could not be retrieved");
+	}
 
-    private static SubscriberParticipantPage getPage(Subscriber subscriber) {
-        try {
-            SubscriberParticipant participant = getParticipant(subscriber);
-            if (participant == null)
-            	throw new AssertionFailedError("The participant for " + subscriber.getName() + " could not be retrieved");
-            IWorkbenchPage activePage = TeamUIPlugin.getActivePage();
-            ISynchronizeView view = (ISynchronizeView)activePage.showView(ISynchronizeView.VIEW_ID);
-            IPage page = ((SynchronizeView)view).getPage(participant);
-            if (page instanceof SubscriberParticipantPage) {
-            	SubscriberParticipantPage subscriberPage = (SubscriberParticipantPage)page;
-            	return subscriberPage;
-            }
-        } catch (PartInitException e) {
-            throw new AssertionFailedError("Cannot show sync view in active page");
-        }
-        throw new AssertionFailedError("The page for " + subscriber.getName() + " could not be retrieved");
-    }
-    
-    private void assertMatchingTrees(IDiffElement parent, TreeItem[] items, IDiffElement[] children) {
-        if ((items == null || items.length == 0) && (children == null || children.length == 0)) {
-            // No children in either case so just return
-            return;
-        }
-        if (items == null || children == null || items.length != children.length) {
-            throw new AssertionFailedError("The number of children of " + parent.getName() + " is " + 
-                    (children == null ? 0: children.length) + " but the view has " + 
-                    (items == null ? 0 : items.length));
-        }
-        for (int i = 0; i < children.length; i++) {
-            IDiffElement element = children[i];
-            TreeItem foundItem = null;
-            for (int j = 0; j < items.length; j++) {
-                TreeItem item = items[j];
-                if (item.getData() == element) {
-                    foundItem = item;
-                    break;
-                }
-            }
-            if (foundItem == null) {
-                throw new AssertionFailedError("Element" + element.getName() + " is in the model but not in the view");
-            } else {
-                assertMatchingTrees(element, foundItem.getItems(), ((IDiffContainer)element).getChildren());
-            }
-        }
-        
-    }
+	private static SubscriberParticipantPage getPage(Subscriber subscriber) {
+		try {
+			SubscriberParticipant participant = getParticipant(subscriber);
+			if (participant == null)
+				throw new AssertionFailedError("The participant for " + subscriber.getName() + " could not be retrieved");
+			IWorkbenchPage activePage = TeamUIPlugin.getActivePage();
+			ISynchronizeView view = (ISynchronizeView)activePage.showView(ISynchronizeView.VIEW_ID);
+			IPage page = ((SynchronizeView)view).getPage(participant);
+			if (page instanceof SubscriberParticipantPage) {
+				SubscriberParticipantPage subscriberPage = (SubscriberParticipantPage)page;
+				return subscriberPage;
+			}
+		} catch (PartInitException e) {
+			throw new AssertionFailedError("Cannot show sync view in active page");
+		}
+		throw new AssertionFailedError("The page for " + subscriber.getName() + " could not be retrieved");
+	}
+	
+	private void assertMatchingTrees(IDiffElement parent, TreeItem[] items, IDiffElement[] children) {
+		if ((items == null || items.length == 0) && (children == null || children.length == 0)) {
+			// No children in either case so just return
+			return;
+		}
+		if (items == null || children == null || items.length != children.length) {
+			throw new AssertionFailedError("The number of children of " + parent.getName() + " is " + 
+					(children == null ? 0: children.length) + " but the view has " + 
+					(items == null ? 0 : items.length));
+		}
+		for (IDiffElement element : children) {
+			TreeItem foundItem = null;
+			for (TreeItem item : items) {
+				if (item.getData() == element) {
+					foundItem = item;
+					break;
+				}
+			}
+			if (foundItem == null) {
+				throw new AssertionFailedError("Element" + element.getName() + " is in the model but not in the view");
+			} else {
+				assertMatchingTrees(element, foundItem.getItems(), ((IDiffContainer)element).getChildren());
+			}
+		}
+		
+	}
 }
